==> apache-reef-0.14.0.tar.gz: apache-reef-0.14.0/lang/cs/Org.Apache.REEF.IO/FileSystem/FileStatus.cs <==
﻿// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
// 
//   http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

using System;

namespace Org.Apache.REEF.IO.FileSystem
{
    /// <summary>
    /// Represents metadata about a file.
    /// </summary>
    public sealed class FileStatus
    {
        /// <summary>
        /// Creates filestatus object.
        /// </summary>
        /// <param name="modificationTime">Last modification time of the file</param>
        /// <param name="lengthBytes">Size of the file in bytes</param>
        internal FileStatus(DateTime modificationTime, long lengthBytes)
        {
            ModificationTime = modificationTime;
            LengthBytes = lengthBytes;
        }

        /// <summary>
        /// Last modification time of the file
        /// </summary>
        public DateTime ModificationTime { get; private set; }

        /// <summary>
        /// Size of the file in bytes.
        /// </summary>
        public long LengthBytes { get; private set; }
    }
}

==> apache-reef-0.16.1.tar.gz: apache-reef-0.16.1/lang/cs/Org.Apache.REEF.IO/FileSystem/FileStatus.cs <==
﻿// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
// 
//   http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

using System;

namespace Org.Apache.REEF.IO.FileSystem
{
    /// <summary>
    /// Represents metadata about a file.
    /// </summary>
    public sealed class FileStatus
    {
        /// <summary>
        /// Creates filestatus object.
        /// </summary>
        /// <param name="modificationTime">Last modification time of the file</param>
        /// <param name="lengthBytes">Size of the file in bytes</param>
        public FileStatus(DateTime modificationTime, long lengthBytes)
        {
            ModificationTime = modificationTime;
            LengthBytes = lengthBytes;
        }

        /// <summary>
        /// Last modification time of the file
        /// </summary>
        public DateTime ModificationTime { get; private set; }

        /// <summary>
        /// Size of the file in bytes.
        /// </summary>
        public long LengthBytes { get; private set; }
    }
}
